" Menu Translations:    Slovak
" Translated By:	Martin Lacko <lacko@host.sk>
" Last Change:		2003 May 11
" This is redirection to slovak menu-translations file

source <sfile>:p:h/menu_slovak_slovak_republic.1250.vim
